Cryptographic Module Validation Program | CSRC
Author: Computer Security Division, Information Technology Laboratory, National Institute of Standards and Technology, U.S. Department of Commerce
Description: Use this form to search for information on validated cryptographic modules. Select the basic search type to search modules on the active validation list. Select the advanced search type to to search modules on the historical and revoked module lists.
Date: 2016-10-11

You are viewing this page in an unauthorized frame window.

This is a potential security issue, you are being redirected to https://csrc.nist.gov.

An official website of the United States government

Official websites use .gov
A .gov website belongs to an official government organization in the United States.

Secure .gov websites use HTTPS
A lock () or https:// means you've safely connected to the .gov website. Share sensitive information only on official, secure websites.

# Cryptographic Module Validation Program CMVP

Share to Facebook Share to Twitter

### Search

Use this form to search for information on validated cryptographic modules.

Select the basic search type to search modules on the active validation list. Select the advanced search type to to search modules on the historical and revoked module lists.

Search Type:
Basic Advanced
Show All
Certificate Number:
Vendor:
Module Name:
Standard:
Module Type:
Validation Status:
Embodiment:
Year Validated:
Level:
Algorithm:
Allowed Algorithms:
Tested Configuration:
Caveat:
Hardware Versions:
Software Versions:
Firmware Versions:
Lab:
Please fix the following:

3486 certificates match the search criteria

Certificate Number | Vendor Name | Module Name | Module Type | Validation Date | Status
--- | --- | --- | --- | --- | ---
3095 | Microsoft Corporation | Cryptographic Primitives Library | Software | 03/22/2018 | Historical
3197 | Microsoft Corporation | Cryptographic Primitives Library | Software | 10/22/2018 07/17/2019 09/08/2020 | Historical
2630 | Red Hat®, Inc. | Red Hat Enterprise Linux OpenSSH Server Cryptographic Module | Software | 05/02/2016 06/17/2016 | Historical
2721 | Red Hat®, Inc. | Red Hat Enterprise Linux Libreswan Cryptographic Module v4.0 | Software | 08/29/2016 12/20/2016 | Historical
2997 | SafeLogic Inc. | CryptoComply for NSS | Software | 08/18/2017 02/07/2018 03/29/2018 | Historical
2441 | Red Hat®, Inc. | Red Hat Enterprise Linux 6.6 OpenSSL Module, Red Hat Enterprise Linux 7.1 OpenSSL Module | Software | 09/08/2015 01/27/2016 02/16/2016 12/21/2016 | Historical
2711 | Red Hat®, Inc. | Red Hat Enterprise Linux NSS Cryptographic Module v4.0 | Software | 08/15/2016 12/19/2016 01/30/2018 | Historical
2779 | DocuSign, Inc. | DocuSign Signature Appliance | Hardware | 10/25/2016 | Historical
2860 | DocuSign, Inc. | DocuSign HSM Appliance | Hardware | 03/08/2017 10/03/2017 04/10/2018 | Historical
2665 | DocuSign, Inc. | DocuSign Signature Appliance | Hardware | 06/21/2016 07/25/2016 | Historical
3141 | DocuSign, Inc. | DocuSign Signature Appliance | Hardware | 02/27/2018 08/17/2018 | Historical
2590 | ARX (Algorithmic Research) | CoSign | Hardware | 03/24/2016 | Historical
3493 | LogRhythm | LogRhythm FIPS Object Module for OpenSSL | Software | 07/17/2019 01/24/2020 | Historical
3495 | Panzura, Inc. | Panzura CloudFS™ FIPS Cryptographic Module | Software | 07/19/2019 | Historical
3711 | Alteryx Inc. | Alteryx Cryptographic Module | Software | 09/21/2020 12/01/2020 | Historical
3176 | Digi International, Inc. | Digi ConnectCore Security Module | Software | 04/26/2018 06/12/2018 | Historical
3488 | ColorTokens | ColorTokens OpenSSL FIPS Object Module | Software | 07/15/2019 | Historical

Created October 11, 2016, Updated October 26, 2022